<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2008 Olivier Meunier and contributors
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------

/* Configuration behaviors */
$core->addBehavior('adminBlogPreferencesForm',array('dcWaveBehaviors','adminBlogPreferencesForm'));
$core->addBehavior('adminBeforeBlogSettingsUpdate',array('dcWaveBehaviors','adminBeforeBlogSettingsUpdate'));
$core->addBehavior('adminBlogPreferencesHeaders',array('dcWaveBehaviors','adminBlogPreferencesHeaders'));

if (!$core->blog->settings->dcwave_enabled) {
	return;
}

/* Insertion behaviors, disabled when not wanted */
$core->addBehavior('adminDashboardHeaders',array('dcWaveBehaviors','adminEditHeaders'));
$core->addBehavior('adminPostHeaders',array('dcWaveBehaviors','adminEditHeaders'));
$core->addBehavior('adminPageHeaders',array('dcWaveBehaviors','adminEditHeaders'));
/* Don't know what the following is for, hence skipping this declaration
$core->addBehavior('adminRelatedHeaders',array('externalMediaBehaviors','jsLoad'));
 */

class dcWaveBehaviors
{
	public static function adminBlogPreferencesForm(&$core,&$settings)
	{
		echo
		'<fieldset><legend>GoogleWave</legend>'.
		'<p><label class="classic">'.
		form::checkbox('dcwave_enabled','1',$settings->dcwave_enabled).
		__('Enable GoogleWave embedding').'</label></p>';

		echo '<div class="two-cols">'."\n";
		/* Box dimension & alignment */
		$align = array(
			__('None') => 'none',
			__('Left') => 'left',
			__('Right') => 'right',
			__('Center') => 'center'
		);
		$previous_align_key = 'none';
		foreach( $align as $k => $v ){
			if ($v == $settings->alignment) { $previous_align_key = $v; }
		}
		echo '<div class="col">'."\n".
		'<h4>'.__('Default box dimension & Alignment').'</h4>'.
		'<p class="field"><label>'.__('Media alignment').
		form::combo('alignment', $align,$previous_align_key).
		'</label></p>'.
		'<p class="field"><label>'.__('Width').
		form::field('width',14,14,$settings->width).
		'</label></p>'.
		'<p class="field"><label>'.__('Height').
		form::field('height',14,14,$settings->height).
		'</label></p>'.
		"\n".'</div>'."\n";
		/* Appearance settings */
		echo '<div class="col">'."\n".
		'<h4>'.__('Default appearance setting').'</h4>'.
		'<p class="field"><label>'.__('Background color').
		form::field('background',14,14,$settings->background,'colorpicker').
		'</label></p>'.
		'<p class="field"><label>'.__('Text color').
		form::field('foreground',14,14,$settings->foreground,'colorpicker').
		'</label></p>'.
		'<p class="field"><label>'.__('Font').
		form::combo('font',dcwaveConfig::fontsList(),dcwaveConfig::fontCode($settings->font)).
		'</label></p>'.
		'<p class="field"><label>'.__('Font size').
		form::field('font_size',14,14,$settings->font_size).
		'</label></p>'.
		"\n".'</div>'."\n".
		'</div> <!-- end two-cols -->'."\n";


		/* Server settings */
		echo '<h4>'.__('Default server settings').'</h4>'."\n".
			'<div class="two-cols">'."\n".
			'<p>'.
			__('You can either use the sandbox setting with server = <em>https://wave.google.com/a/wavesandbox.com/</em> and prefix = <em>wavesandbox.com!w+</em>, the preview configuration with server = <em>https://wave.google.com/wave/</em> and prefix = <em>dcwave.com!w+</em> or enter your own personal values. The <em>waveID</em> will be concatenated after the prefix parameter.').
			'</p>'.
			'<div class="col">'."\n".
			'<p><label class="classic">'.__('Wave server').' '.
			form::field('server',50,180,$settings->server).
			'</label></p>'.
			"\n".'</div>'."\n".
			'<div class="col">'."\n".
			'<p><label class="classic">'.__('Wave prefix').
			form::field('prefix',30,50,$settings->prefix).
			'<em> waveID</em></label></p>'.
			'<p class="form-note">'.
			__("In the <em>prefix</em> parameter, '%252B' will be equivalent to '+'.").
			'</p>'.
			"\n".'</div>'."\n".
			'</div> <!-- end two-cols -->'."\n";

		echo '</fieldset>';
	}
	
	public static function adminBeforeBlogSettingsUpdate(&$settings)
	{
		$settings->setNameSpace('dcwave');

		$settings->put('dcwave_enabled',!empty($_POST['dcwave_enabled']),'boolean');
		/* Box */
		$settings->put('width',$_POST['width'],'string');
		$settings->put('height',$_POST['height'],'string');
		$settings->put('alignment',$_POST['alignment'],'string');
		/* Appearance */
		$settings->put('background',$_POST['background'],'string');
		$settings->put('foreground',$_POST['foreground'],'string');
		$settings->put('font',dcwaveConfig::fontDef($_POST['font']),'string');
		$settings->put('font_size',dcwaveConfig::adjustFontSize($_POST['font_size']),'string');
		/* Server */
		$settings->put('server',$_POST['server'],'string');
		/* QUIRK: encoding/decoding '%252B' to '+' */
		$settings->put('prefix',str_replace('%252B','+',$_POST['prefix']),'string');

		$settings->setNameSpace('system');
	}

	public static function adminBlogPreferencesHeaders()
	{
		return dcPage::jsColorPicker();
	}

	public static function adminEditHeaders()
	{
		return
		'<script type="text/javascript" src="index.php?pf=dcWave/js/post.js"></script>'."\n".
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		dcPage::jsVar('jsToolBar.prototype.elements.gwave.title',__('Add a Google Wave')).
		"\n//]]>\n".
		"</script>\n";
	}
}
?>
