<?php
# -- BEGIN LICENSE BLOCK ----------------------------------
#
# This file is part of Dotclear 2.
#
# Copyright (c) 2003-2009 Olivier Meunier and contributors
# Licensed under the GPL version 2.0 license.
# See LICENSE file or
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
#
# -- END LICENSE BLOCK ------------------------------------
if (!defined('DC_CONTEXT_ADMIN')) { return; }

$gw_id = $gw_title = $gw_url = null;
$wave_page = !empty($_POST['wave_page']) ? $_POST['wave_page'] : null;
// https://wave.google.com/wave/?pli=1#restored:wave:dcwave.com!w%252BoeJRwxygA

if ($wave_page)
{
	$gw_server = $_POST['gw_server'];
	/* QUIRK: encoding/decoding '%252B' to '+' */
	$gw_prefix = str_replace('+', '%252B', $_POST['gw_prefix']);
	try
	{
		/* QUIRK: encoding/decoding '%252B' to '+' */
		if (preg_match('#'.$gw_prefix.'(.+?)(\.|&|$)#',str_replace('+','%252B',$wave_page),$waveID))
		{
			$gw_id = $waveID[1];
		} else {
			throw new Exception(__('Cannot parse waveID / URL !'));
		}
		$gw_url = $wave_page;
	}
	catch (Exception $e)
	{
		$core->error->add($e->getMessage());
	}
	/* (un)QUIRK: encoding/decoding '%252B' to '+' */
	$gw_prefix = str_replace('%252B','+',$_POST['gw_prefix']);
}
?>
<html>
<head>
	<title><?php echo __('Google Wave toolbox') ?></title>
	<?php echo dcPage::jsLoad('index.php?pf=dcWave/js/popup.js'); ?>
	<?php echo dcPage::jsColorPicker(); ?>
	<?php
	echo '<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		'var fonts = new Array();'."\n";
	foreach (dcwaveConfig::rawFontsList() as $code => $font)
	{
		echo 'fonts[\''.$code.'\'] = \''.str_replace('\\"','"',$font).'\';'."\n";
	}
	echo 'var gw_fallback_msg = \''
		.__('dcWave seems to be disabled, cannot load the Wave with ID').
		"';\n";
	echo "\n//]]>\n".
		"</script>\n";
	?>
</head>

<body>
<?php
echo '<h2>'.__('Google Wave toolbox').'</h2>';

if (!$gw_id)
{
	echo '<form action="" method="post">';

	/* Default values */
	$core->blog->settings->setNamespace('dcwave');
	$gw_server = $core->blog->settings->server;
	$gw_prefix = $core->blog->settings->prefix;
	$core->blog->settings->setNamespace('sytem');

	/* fields */
	echo '<h3>'.__('Server settings').'</h3>'."\n".
		'<p class="field"><label>'.__('Wave server').' '.
		form::field('gw_server',50,180,$gw_server).
		'</label></p>'.
		'<p class="field"><label>'.__('Wave prefix').
		form::field('gw_prefix',20,50,$gw_prefix).
		'</label></p>'.
		'<p class="form-note"><br />'.
		__("In the <em>prefix</em> parameter, '%252B' will be equivalent to '+'.").
		'</p>';

	/* URL */
	echo
		'<h3>URL</h3>'.
		'<p>'.
		__('Please enter the URL of the page containing the wave you want to include in your post.').'</p>'.
		'<p><label>'.__('Page URL:').' '.
		form::field('wave_page',50,250,html::escapeHTML($wave_page)).'</label></p>';

	echo
		'<p><input type="submit" value="'.__('ok').'" />'.
		$core->formNonce().'</p>'.
		'</form>';
} 
else {
	$waveID = $gw_id;

	/* Prevualisation */
	echo
	'<div id="preview" style="margin: 1em auto; padding : 0.2em; border : 2px solid black;'.
	'text-align: center;background : white; color : black;">'."\n".
	'</div>'.
	'<form id="media-insert-form" action="" method="post">';
	
	/* Default values */
	$core->blog->settings->setNamespace('dcwave');
	$gw_bg = $core->blog->settings->background;
	$gw_fg = $core->blog->settings->foreground;
	$gw_font = $core->blog->settings->font;
	$gw_font_size = $core->blog->settings->font_size;
	$gw_width = $core->blog->settings->width;
	$gw_height = $core->blog->settings->height;
	$gw_alignment = $core->blog->settings->alignment;
	$core->blog->settings->setNamespace('sytem');

	echo '<fieldset>';
	/* Summarise */
	echo '<legend>'.__('Wave parameters').'</legend>'."\n".
		'<ul><li>'.__('Wave server').' : <em>'.$gw_server.'</em></li>'.
		'<li>'.__('Wave prefix').' : <em>'.$gw_prefix.'</em></li>'.
		'<li>'.__('Wave ID').' : <em>'.$waveID.'</em></li></ul>';

	/* Fieldsets separation */
	echo 
		'</fieldset><fieldset>'.
		'<legend>'.__('Appearance').'</legend>';

	/* !-- BEGIN columns */
	echo '<div class="two-cols"><div class="col">';
	/* Alignment */
	$i_align = array(
		'none' => array(__('None'),0),
		'left' => array(__('Left'),0),
		'right' => array(__('Right'),0),
		'center' => array(__('Center'),0)
	);
	$i_align[$gw_alignment][1] = 1;
	echo '<h3>'.__('Media alignment').'</h3>';
	echo '<p>';
	foreach ($i_align as $k => $v) {
		echo '<label class="classic">'.
		form::radio(array('alignment'),$k,$v[1]).' '.$v[0].'</label><br /> ';
	}
	echo '</p>';
	/* Box dimension */
	echo '<h3>'.__('Box dimension').'</h3>'.
	'<p class="field"><label>'.__('Width').' '.
	form::field('gw_width',14,14,html::escapeHTML($gw_width), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Height').' '.
	form::field('gw_height',14,14,html::escapeHTML($gw_height), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>';

	echo '</div><div class="col">';
	
	/* Misc. appearance */
	echo '<h3>'.__('Other appearance setting').'</h3>'.
	'<p class="field"><label>'.__('Background color').' '.
	form::field('gw_bg',14,14,html::escapeHTML($gw_bg),'colorpicker',
	'', false, 'onchange="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Text color').' '.
	form::field('gw_fg',14,14,html::escapeHTML($gw_fg),'colorpicker', 
	'', false, 'onchange="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Default font').' '.
	form::combo('gw_font',dcwaveConfig::fontsList(),dcwaveConfig::fontCode($gw_font), '',
	'', false, 'onchange="update_preview();"').
	'</label></p>'.
	'<p class="field"><label>'.__('Default font size').' '.
	form::field('gw_font_size',14,14,html::escapeHTML($gw_font_size), '',
	'', false, 'onkeyup="update_preview();"').
	'</label></p>';
	/* !-- END of columns */
	echo '</div></div>';
	/* Fieldsets separation */
	echo '</fieldset><fieldset>';
	/* TITLE */
	echo
		'<legend>'.__('Media title').'</legend>'.
		'<p class="field"><label>'.__('Title:').' '.
		form::field('gw_title',50,150,html::escapeHTML($gw_title)).'</label></p>';
	echo 
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		"$('#gw_title').focus()".
		"\n//]]>\n".
		"</script>\n";
	
	echo
	'<p><a id="media-insert-cancel" class="button" href="#">'.__('Cancel').'</a> - '.
	'<strong><a id="media-insert-ok" class="button" href="#">'.__('Insert').'</a></strong>'.
	form::hidden('gw_server',html::escapeHTML($gw_server)).
	form::hidden('gw_prefix',html::escapeHTML($gw_prefix)).
	form::hidden('gw_id',html::escapeHTML($gw_id)).
	form::hidden('gw_url',html::escapeHTML($gw_url)).
	'</p>'.
	'<p>'.$core->formNonce().'</p>'.
	'</fieldset>'.
	'</form>';
}
?>
</body>
</html>
